.. image:: https://github.com/ryjmacdonell/gimbal/blob/master/docs/gimbal_logo.svg

.. image:: https://travis-ci.org/ryjmacdonell/gimbal.svg?branch=master
    :target: https://travis-ci.org/ryjmacdonell/gimbal

.. image:: https://readthedocs.org/projects/gimbal-editor/badge/?version=latest
    :target: https://gimbal-editor.readthedocs.io/en/latest/?badge=latest

.. image:: https://codecov.io/gh/ryjmacdonell/gimbal/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/ryjmacdonell/gimbal

.. image:: https://badge.fury.io/py/gimbal.svg
    :target: https://badge.fury.io/py/gimbal

Gimbal is a package for importing, creating, editing and querying
three-dimensional molecular geometries. It specializes in intramolecular
transformations relevant to dynamical simulation.

Installation
------------
To install the latest release from PyPI, use::

    $ pip install gimbal

Alternatively, clone the repository and use setup.py to install via::

    $ git clone https://github.com/ryjmacdonell/gimbal.git
    $ cd gimbal/
    $ python setup.py install

Installation will also add several executables from `bin/` to your path for
easily editing recognized file formats.

Requirements
------------
Requires at least Python 3.4, NumPy v1.6.0, SciPy v0.9.0 and PyParsing v2.2.0

Documentation
-------------
For additional documentation, see the
`documentation page <https://gimbal-editor.readthedocs.io/en/latest>`_.

Author
------
Ryan J. MacDonell
